==> custom-webpack-11.0.0-beta.4.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## 11.0.0-beta.4 (2020-12-16)


### Bug Fixes

* **custom-webpack:** fix loaders merge scenario ([#909](https://github.com/just-jeb/angular-builders/issues/909)) ([0f0ad3d](https://github.com/just-jeb/angular-builders/commit/0f0ad3d174ea589538c4474b0509ad3b5f925bf1))



## 11.0.0-beta.3 (2020-12-15)

**Note:** Version bump only for package @angular-builders/custom-webpack





## 11.0.0-beta.2 (2020-12-14)

**Note:** Version bump only for package @angular-builders/custom-webpack





## [11.0.0-beta.1](https://github.com/just-jeb/angular-builders/compare/@angular-builders/custom-webpack@10.1.0-beta.0...@angular-builders/custom-webpack@11.0.0-beta.1) (2020-11-17)

### ⚠ BREAKING CHANGES

- **deps:** update to angular 11 (#874)

### Miscellaneous Chores

- **deps:** update to angular 11 ([#874](https://github.com/just-jeb/angular-builders/issues/874)) ([e0900dd](https://github.com/just-jeb/angular-builders/commit/e0900dd5e89750a6d7c129ce82d71354dc8882be)), closes [#854](https://github.com/just-jeb/angular-builders/issues/854) [#873](https://github.com/just-jeb/angular-builders/issues/873)

## [11.0.0-beta.0](https://github.com/just-jeb/angular-builders/compare/@angular-builders/custom-webpack@10.1.0-beta.0...@angular-builders/custom-webpack@11.0.0-beta.0) (2020-11-17)

### ⚠ BREAKING CHANGES

- **deps:** update to angular 11 (#874)

### Miscellaneous Chores

- **deps:** update to angular 11 ([#874](https://github.com/just-jeb/angular-builders/issues/874)) ([e0900dd](https://github.com/just-jeb/angular-builders/commit/e0900dd5e89750a6d7c129ce82d71354dc8882be)), closes [#854](https://github.com/just-jeb/angular-builders/issues/854) [#873](https://github.com/just-jeb/angular-builders/issues/873)

## 10.1.0-beta.0 (2020-09-10)

- feat(custom-webpack): add extract-i18n builder (#832) ([15f95d0](https://github.com/just-jeb/angular-builders/commit/15f95d0)), closes [#832](https://github.com/just-jeb/angular-builders/issues/832)

## <small>10.0.2-beta.0 (2020-09-09)</small>

- Fix CHANGELOG links (#834) ([001b4ab](https://github.com/just-jeb/angular-builders/commit/001b4ab)), closes [#834](https://github.com/just-jeb/angular-builders/issues/834)

## <small>10.0.1 (2020-09-09)</small>

**Note:** Version bump only for package @angular-builders/custom-webpack

## <small>10.0.1-beta.1 (2020-09-06)</small>

- chore: update dependencies (#831) ([b475080](https://github.com/just-jeb/angular-builders/commit/b475080)), closes [#831](https://github.com/just-jeb/angular-builders/issues/831)

## <small>10.0.1-beta.0 (2020-09-01)</small>

- chore(deps): bump ts-node from 8.10.2 to 9.0.0 ([7de38ff](https://github.com/just-jeb/angular-builders/commit/7de38ff))

## 10.0.0 (2020-07-21)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 10.0.0-beta.1 (2020-07-13)

- feat(custom-webpack): export common (#793) ([1cb73d4](https://github.com/just-jeb/angular-builders/commit/1cb73d4)), closes [#793](https://github.com/just-jeb/angular-builders/issues/793)

## 10.0.0-beta.0 (2020-06-25)

- build!: update to Angular 10 (#782) ([409f356](https://github.com/just-jeb/angular-builders/commit/409f356)), closes [#782](https://github.com/just-jeb/angular-builders/issues/782)

## <small>9.2.1-beta.0 (2020-06-23)</small>

- fix(custom-webpack): schema validation error ([fe1cda0](https://github.com/just-jeb/angular-builders/commit/fe1cda0))

## 9.2.0 (2020-06-23)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 9.2.0-beta.0 (2020-04-15)

- docs(custom-webpack): update README ([0b81440](https://github.com/just-jeb/angular-builders/commit/0b81440))
- feat(custom-webpack): pass target options to custom webpack config function (#721) ([7a44528](https://github.com/just-jeb/angular-builders/commit/7a44528)), closes [#721](https://github.com/just-jeb/angular-builders/issues/721) [#683](https://github.com/just-jeb/angular-builders/issues/683)

## 9.1.0 (2020-04-05)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 9.1.0-beta.1 (2020-03-29)

- fix: adjust devkit version range to fit 0.9xx.0 (#709) ([99e061f](https://github.com/just-jeb/angular-builders/commit/99e061f)), closes [#709](https://github.com/just-jeb/angular-builders/issues/709)

## 9.1.0-beta.0 (2020-02-27)

- feat(custom-webpack): support TS for indexTransform (#689) ([f97905c](https://github.com/just-jeb/angular-builders/commit/f97905c)), closes [#689](https://github.com/just-jeb/angular-builders/issues/689)

## <small>9.0.1-beta.0 (2020-02-23)</small>

- docs: minor fixes (#688) ([7cd52f8](https://github.com/just-jeb/angular-builders/commit/7cd52f8)), closes [#688](https://github.com/just-jeb/angular-builders/issues/688)

## 9.0.0 (2020-02-23)

- ci(release): publish ([f0ce8bc](https://github.com/just-jeb/angular-builders/commit/f0ce8bc))
- docs: update README and MIGRATION for v9 (#685) ([92ec06d](https://github.com/just-jeb/angular-builders/commit/92ec06d)), closes [#685](https://github.com/just-jeb/angular-builders/issues/685)

## 9.0.0-beta.2 (2020-02-23)

- docs: update README and MIGRATION for v9 (#685) ([92ec06d](https://github.com/just-jeb/angular-builders/commit/92ec06d)), closes [#685](https://github.com/just-jeb/angular-builders/issues/685)

## 9.0.0-beta.1 (2020-01-28)

- docs: add 'next' tag badges (#672) ([441adec](https://github.com/just-jeb/angular-builders/commit/441adec)), closes [#672](https://github.com/just-jeb/angular-builders/issues/672)

## 9.0.0-beta.0 (2020-01-04)

- ci: use verdaccio for e2e ([23f9235](https://github.com/just-jeb/angular-builders/commit/23f9235))
- build!: direct dependency on @angular-devkit 9 ([6f0ac12](https://github.com/just-jeb/angular-builders/commit/6f0ac12))

## [8.4.1](https://github.com/just-jeb/angular-builders/tree/master/packages/custom-webpack/compare/@angular-builders/custom-webpack@8.4.0...@angular-builders/custom-webpack@8.4.1) (2019-11-29)

### Bug Fixes

- **custom-webpack:** support exporting function in config written in TS ([#627](https://github.com/just-jeb/angular-builders/issues/627)) ([9ecde07](https://github.com/just-jeb/angular-builders/commit/9ecde07adc80291993d59a363ce7330996bde1f4))

# [8.4.0](https://github.com/just-jeb/angular-builders/tree/master/packages/custom-webpack/compare/@angular-builders/custom-webpack@8.3.0...@angular-builders/custom-webpack@8.4.0) (2019-11-19)

### Features

- **custom-webpack:** support Webpack config written in TS ([#626](https://github.com/just-jeb/angular-builders/issues/626)) ([479fa0b](https://github.com/just-jeb/angular-builders/commit/479fa0bb1664ec618d482c15f0e52ba9d58acb07))

==> custom-webpack-11.0.1-beta.4.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

### 11.0.1-beta.4 (2021-02-03)

**Note:** Version bump only for package @angular-builders/custom-webpack





### 11.0.1-beta.3 (2021-02-03)

**Note:** Version bump only for package @angular-builders/custom-webpack





### 11.0.1-beta.2 (2021-02-03)

**Note:** Version bump only for package @angular-builders/custom-webpack





### 11.0.1-beta.1 (2021-01-14)

**Note:** Version bump only for package @angular-builders/custom-webpack





### 11.0.1-beta.0 (2020-12-27)

**Note:** Version bump only for package @angular-builders/custom-webpack





## [11.0.0](https://github.com/just-jeb/angular-builders/compare/@angular-builders/custom-webpack@11.0.0-beta.6...@angular-builders/custom-webpack@11.0.0) (2020-12-27)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 11.0.0-beta.6 (2020-12-27)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 11.0.0-beta.5 (2020-12-22)

### Bug Fixes

- **custom-webpack:** allow merging loader name with loader object ([#912](https://github.com/just-jeb/angular-builders/issues/912)) ([a89a35d](https://github.com/just-jeb/angular-builders/commit/a89a35d30276a3d284d304ee710442ee03da351b))

## 11.0.0-beta.4 (2020-12-16)

### Bug Fixes

- **custom-webpack:** fix loaders merge scenario ([#909](https://github.com/just-jeb/angular-builders/issues/909)) ([0f0ad3d](https://github.com/just-jeb/angular-builders/commit/0f0ad3d174ea589538c4474b0509ad3b5f925bf1))

## 11.0.0-beta.3 (2020-12-15)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 11.0.0-beta.2 (2020-12-14)

**Note:** Version bump only for package @angular-builders/custom-webpack

## [11.0.0-beta.1](https://github.com/just-jeb/angular-builders/compare/@angular-builders/custom-webpack@10.1.0-beta.0...@angular-builders/custom-webpack@11.0.0-beta.1) (2020-11-17)

### ⚠ BREAKING CHANGES

- **deps:** update to angular 11 (#874)

### Miscellaneous Chores

- **deps:** update to angular 11 ([#874](https://github.com/just-jeb/angular-builders/issues/874)) ([e0900dd](https://github.com/just-jeb/angular-builders/commit/e0900dd5e89750a6d7c129ce82d71354dc8882be)), closes [#854](https://github.com/just-jeb/angular-builders/issues/854) [#873](https://github.com/just-jeb/angular-builders/issues/873)

## [11.0.0-beta.0](https://github.com/just-jeb/angular-builders/compare/@angular-builders/custom-webpack@10.1.0-beta.0...@angular-builders/custom-webpack@11.0.0-beta.0) (2020-11-17)

### ⚠ BREAKING CHANGES

- **deps:** update to angular 11 (#874)

### Miscellaneous Chores

- **deps:** update to angular 11 ([#874](https://github.com/just-jeb/angular-builders/issues/874)) ([e0900dd](https://github.com/just-jeb/angular-builders/commit/e0900dd5e89750a6d7c129ce82d71354dc8882be)), closes [#854](https://github.com/just-jeb/angular-builders/issues/854) [#873](https://github.com/just-jeb/angular-builders/issues/873)

## 10.1.0-beta.0 (2020-09-10)

- feat(custom-webpack): add extract-i18n builder (#832) ([15f95d0](https://github.com/just-jeb/angular-builders/commit/15f95d0)), closes [#832](https://github.com/just-jeb/angular-builders/issues/832)

## <small>10.0.2-beta.0 (2020-09-09)</small>

- Fix CHANGELOG links (#834) ([001b4ab](https://github.com/just-jeb/angular-builders/commit/001b4ab)), closes [#834](https://github.com/just-jeb/angular-builders/issues/834)

## <small>10.0.1 (2020-09-09)</small>

**Note:** Version bump only for package @angular-builders/custom-webpack

## <small>10.0.1-beta.1 (2020-09-06)</small>

- chore: update dependencies (#831) ([b475080](https://github.com/just-jeb/angular-builders/commit/b475080)), closes [#831](https://github.com/just-jeb/angular-builders/issues/831)

## <small>10.0.1-beta.0 (2020-09-01)</small>

- chore(deps): bump ts-node from 8.10.2 to 9.0.0 ([7de38ff](https://github.com/just-jeb/angular-builders/commit/7de38ff))

## 10.0.0 (2020-07-21)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 10.0.0-beta.1 (2020-07-13)

- feat(custom-webpack): export common (#793) ([1cb73d4](https://github.com/just-jeb/angular-builders/commit/1cb73d4)), closes [#793](https://github.com/just-jeb/angular-builders/issues/793)

## 10.0.0-beta.0 (2020-06-25)

- build!: update to Angular 10 (#782) ([409f356](https://github.com/just-jeb/angular-builders/commit/409f356)), closes [#782](https://github.com/just-jeb/angular-builders/issues/782)

## <small>9.2.1-beta.0 (2020-06-23)</small>

- fix(custom-webpack): schema validation error ([fe1cda0](https://github.com/just-jeb/angular-builders/commit/fe1cda0))

## 9.2.0 (2020-06-23)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 9.2.0-beta.0 (2020-04-15)

- docs(custom-webpack): update README ([0b81440](https://github.com/just-jeb/angular-builders/commit/0b81440))
- feat(custom-webpack): pass target options to custom webpack config function (#721) ([7a44528](https://github.com/just-jeb/angular-builders/commit/7a44528)), closes [#721](https://github.com/just-jeb/angular-builders/issues/721) [#683](https://github.com/just-jeb/angular-builders/issues/683)

## 9.1.0 (2020-04-05)

**Note:** Version bump only for package @angular-builders/custom-webpack

## 9.1.0-beta.1 (2020-03-29)

- fix: adjust devkit version range to fit 0.9xx.0 (#709) ([99e061f](https://github.com/just-jeb/angular-builders/commit/99e061f)), closes [#709](https://github.com/just-jeb/angular-builders/issues/709)

## 9.1.0-beta.0 (2020-02-27)

- feat(custom-webpack): support TS for indexTransform (#689) ([f97905c](https://github.com/just-jeb/angular-builders/commit/f97905c)), closes [#689](https://github.com/just-jeb/angular-builders/issues/689)

## <small>9.0.1-beta.0 (2020-02-23)</small>

- docs: minor fixes (#688) ([7cd52f8](https://github.com/just-jeb/angular-builders/commit/7cd52f8)), closes [#688](https://github.com/just-jeb/angular-builders/issues/688)

## 9.0.0 (2020-02-23)

- ci(release): publish ([f0ce8bc](https://github.com/just-jeb/angular-builders/commit/f0ce8bc))
- docs: update README and MIGRATION for v9 (#685) ([92ec06d](https://github.com/just-jeb/angular-builders/commit/92ec06d)), closes [#685](https://github.com/just-jeb/angular-builders/issues/685)

## 9.0.0-beta.2 (2020-02-23)

- docs: update README and MIGRATION for v9 (#685) ([92ec06d](https://github.com/just-jeb/angular-builders/commit/92ec06d)), closes [#685](https://github.com/just-jeb/angular-builders/issues/685)

## 9.0.0-beta.1 (2020-01-28)

- docs: add 'next' tag badges (#672) ([441adec](https://github.com/just-jeb/angular-builders/commit/441adec)), closes [#672](https://github.com/just-jeb/angular-builders/issues/672)

## 9.0.0-beta.0 (2020-01-04)

- ci: use verdaccio for e2e ([23f9235](https://github.com/just-jeb/angular-builders/commit/23f9235))
- build!: direct dependency on @angular-devkit 9 ([6f0ac12](https://github.com/just-jeb/angular-builders/commit/6f0ac12))

## [8.4.1](https://github.com/just-jeb/angular-builders/tree/master/packages/custom-webpack/compare/@angular-builders/custom-webpack@8.4.0...@angular-builders/custom-webpack@8.4.1) (2019-11-29)

### Bug Fixes

- **custom-webpack:** support exporting function in config written in TS ([#627](https://github.com/just-jeb/angular-builders/issues/627)) ([9ecde07](https://github.com/just-jeb/angular-builders/commit/9ecde07adc80291993d59a363ce7330996bde1f4))

# [8.4.0](https://github.com/just-jeb/angular-builders/tree/master/packages/custom-webpack/compare/@angular-builders/custom-webpack@8.3.0...@angular-builders/custom-webpack@8.4.0) (2019-11-19)

### Features

- **custom-webpack:** support Webpack config written in TS ([#626](https://github.com/just-jeb/angular-builders/issues/626)) ([479fa0b](https://github.com/just-jeb/angular-builders/commit/479fa0bb1664ec618d482c15f0e52ba9d58acb07))
